==> robotframework-sqless-0.0.2.tar.gz: robotframework-sqless-0.0.2/README.md <==
![Robot Tests](https://github.com/eternalconcert/robotframework-sqless/workflows/Robot%20Tests/badge.svg?branch=master)

# Robot Framework - SQLess

``robotframework-sqless`` is a  SQL abstraction library for [Robot Framework](https://robotframework.org/)

## Usage

```bash
pip install robotframework-sqless
```

## Example testcase
|                     |                           |                     |                     |                       |
| ----------------    | --------------------------| ------------------- | ------------------- | --------------------- |
| *** Settings ***    |                           |                     |                     |                       |
| Library             | SQLess                    |                     |                     |                       |
| *** Test Cases ***  |                           |                     |                     |                       |
| Get Users By Filter |                           |                     |                     |                       |
|                     | ${users}                  | Get By Filter       | Users               | username=TestUser     |
|                     | Length Should Be          | ${users}            | 1                   |                       |

The example presumes there is a database with a user table and at least a column `username`.

## Schema definition
The database schema must be defined in an .yml file. For the above example, the following file should apply:

```yaml
database_config:
  dbms: sqlite
  db: sqless.db

schema:
  users:
    tablename: user
    fields:
      id: integer
      username: char
```

==> robotframework-sqless-0.0.4.tar.gz: robotframework-sqless-0.0.4/README.md <==
![Robot Tests](https://github.com/eternalconcert/robotframework-sqless/workflows/Robot%20Tests/badge.svg?branch=master)

# Robot Framework - SQLess

``robotframework-sqless`` is a  SQL abstraction library for [Robot Framework](https://robotframework.org/)

## Usage

```bash
pip install robotframework-sqless
```

## Example testcase
|                     |                           |                     |                     |                       |
| ----------------    | --------------------------| ------------------- | ------------------- | --------------------- |
| *** Settings ***    |                           |                     |                     |                       |
| Library             | SQLess                    | schema.yml          | db_config.yml       |                       |
| *** Test Cases ***  |                           |                     |                     |                       |
| Get Users By Filter |                           |                     |                     |                       |
|                     | ${users}                  | Get By Filter       | Users               | username=TestUser     |
|                     | Length Should Be          | ${users}            | 1                   |                       |

The example presumes there is a database with a user table and at least a column `username`.

## Schema definition
The database schema must be defined in an .yml file. For the above example, the following file should apply:

```yaml
database_config:
  dbms: sqlite
  db: sqless.db

schema:
  users:
    tablename: user
    fields:
      id: integer
      username: char
```
